@@ -1,4 +1,4 @@
-/*	$OpenBSD: gbr.c,v 1.30 2024/02/21 09:17:06 tb Exp $ */
+/*	$OpenBSD: gbr.c,v 1.31 2025/04/02 09:51:42 tb Exp $ */
 /*
  * Copyright (c) 2020 Claudio Jeker <claudio@openbsd.org>
  *
@@ -19,6 +19,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <vis.h>
 
 #include <openssl/x509.h>
 
@@ -26,6 +27,9 @@
 
 extern ASN1_OBJECT	*gbr_oid;
 
+#define VCARD_START	"BEGIN:VCARD\r\nVERSION:4.0\r\n"
+#define VCARD_START_LEN	(sizeof(VCARD_START) - 1)
+
 /*
  * Parse a full RFC 6493 file and signed by the certificate "cacert"
  * (the latter is optional and may be passed as NULL to disable).
@@ -48,9 +52,18 @@ gbr_parse(X509 **x509, const char *fn, int talid, const unsigned char *der,
 	if ((gbr = calloc(1, sizeof(*gbr))) == NULL)
 		err(1, NULL);
 	gbr->signtime = signtime;
-	if ((gbr->vcard = strndup(cms, cmsz)) == NULL)
+
+	if (cmsz < VCARD_START_LEN ||
+	    strncmp(cms, VCARD_START, VCARD_START_LEN) != 0) {
+		warnx("%s: Ghostbusters record with invalid vCard", fn);
+		goto out;
+	}
+	if ((gbr->vcard = calloc(cmsz + 1, 4)) == NULL)
 		err(1, NULL);
+	(void)strvisx(gbr->vcard, cms, cmsz, VIS_SAFE);
+
 	free(cms);
+	cms = NULL;
 
 	if (!x509_get_aia(*x509, fn, &gbr->aia))
 		goto out;
@@ -83,6 +96,7 @@ gbr_parse(X509 **x509, const char *fn, int talid, const unsigned char *der,
 	return gbr;
 
  out:
+	free(cms);
 	gbr_free(gbr);
 	X509_free(*x509);
 	*x509 = NULL;
