@@ -1,4 +1,4 @@
-/*	$OpenBSD: main.c,v 1.278 2025/01/03 10:14:32 job Exp $ */
+/*	$OpenBSD: main.c,v 1.281 2025/04/03 14:29:44 tb Exp $ */
 /*
  * Copyright (c) 2021 Claudio Jeker <claudio@openbsd.org>
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
@@ -488,7 +488,7 @@ queue_add_from_tal(struct tal *tal)
  * Add a manifest (MFT) found in an X509 certificate, RFC 6487.
  */
 static void
-queue_add_from_cert(const struct cert *cert)
+queue_add_from_cert(const struct cert *cert, struct nca_tree *ncas)
 {
 	struct repo		*repo;
 	struct fqdnlistentry	*le;
@@ -549,6 +549,7 @@ queue_add_from_cert(const struct cert *cert)
 			err(1, NULL);
 	}
 
+	cert_insert_nca(ncas, cert, repo);
 	entityq_add(npath, nfile, RTYPE_MFT, DIR_UNKNOWN, repo, NULL, 0,
 	    cert->talid, cert->certid, NULL);
 }
@@ -562,7 +563,7 @@ queue_add_from_cert(const struct cert *cert)
 static void
 entity_process(struct ibuf *b, struct stats *st, struct vrp_tree *tree,
     struct brk_tree *brktree, struct vap_tree *vaptree,
-    struct vsp_tree *vsptree)
+    struct vsp_tree *vsptree, struct nca_tree *ncatree)
 {
 	enum rtype	 type;
 	struct tal	*tal;
@@ -619,7 +620,7 @@ entity_process(struct ibuf *b, struct stats *st, struct vrp_tree *tree,
 		switch (cert->purpose) {
 		case CERT_PURPOSE_TA:
 		case CERT_PURPOSE_CA:
-			queue_add_from_cert(cert);
+			queue_add_from_cert(cert, ncatree);
 			break;
 		case CERT_PURPOSE_BGPSEC_ROUTER:
 			cert_insert_brks(brktree, cert);
@@ -641,6 +642,7 @@ entity_process(struct ibuf *b, struct stats *st, struct vrp_tree *tree,
 		if (mft->seqnum_gap)
 			repo_stat_inc(rp, talid, type, STYPE_SEQNUM_GAP);
 		queue_add_from_mft(mft);
+		cert_remove_nca(ncatree, mft->certid, rp);
 		mft_free(mft);
 		break;
 	case RTYPE_CRL:
@@ -768,6 +770,7 @@ sum_stats(const struct repo *rp, const struct repotalstats *in, void *arg)
 	out->mfts_gap += in->mfts_gap;
 	out->certs += in->certs;
 	out->certs_fail += in->certs_fail;
+	out->certs_nonfunc += in->certs_nonfunc;
 	out->roas += in->roas;
 	out->roas_fail += in->roas_fail;
 	out->roas_invalid += in->roas_invalid;
@@ -987,6 +990,7 @@ main(int argc, char *argv[])
 	struct vsp_tree	 vsps = RB_INITIALIZER(&vsps);
 	struct brk_tree	 brks = RB_INITIALIZER(&brks);
 	struct vap_tree	 vaps = RB_INITIALIZER(&vaps);
+	struct nca_tree	 ncas = RB_INITIALIZER(&ncas);
 	struct rusage	 ru;
 	struct timespec	 start_time, now_time;
 
@@ -1242,7 +1246,7 @@ main(int argc, char *argv[])
 	    NULL)
 		err(1, NULL);
 	if ((rrdpq = msgbuf_new_reader(sizeof(size_t), io_parse_hdr, NULL)) ==
-	   NULL)
+	    NULL)
 		err(1, NULL);
 
 	/*
@@ -1405,7 +1409,7 @@ main(int argc, char *argv[])
 			}
 			while ((b = io_buf_get(queues[0])) != NULL) {
 				entity_process(b, &stats, &vrps, &brks, &vaps,
-				    &vsps);
+				    &vsps, &ncas);
 				ibuf_free(b);
 			}
 		}
@@ -1498,7 +1502,7 @@ main(int argc, char *argv[])
 	}
 	repo_stats_collect(sum_repostats, &stats.repo_stats);
 
-	if (outputfiles(&vrps, &brks, &vaps, &vsps, &stats))
+	if (outputfiles(&vrps, &brks, &vaps, &vsps, &ncas, &stats))
 		rc = 1;
 
 	printf("Processing time %lld seconds "
@@ -1522,8 +1526,9 @@ main(int argc, char *argv[])
 		    stats.repo_tal_stats.spls_invalid);
 	}
 	printf("BGPsec Router Certificates: %u\n", stats.repo_tal_stats.brks);
-	printf("Certificates: %u (%u invalid)\n",
-	    stats.repo_tal_stats.certs, stats.repo_tal_stats.certs_fail);
+	printf("Certificates: %u (%u invalid, %u non-functional)\n",
+	    stats.repo_tal_stats.certs, stats.repo_tal_stats.certs_fail,
+	    stats.repo_tal_stats.certs_nonfunc);
 	printf("Trust Anchor Locators: %u (%u invalid)\n",
 	    stats.tals, talsz - stats.tals);
 	printf("Manifests: %u (%u failed parse, %u seqnum gaps)\n",
