@@ -1,4 +1,4 @@
-/*	$OpenBSD: rsync.c,v 1.56 2024/11/21 13:32:27 claudio Exp $ */
+/*	$OpenBSD: rsync.c,v 1.57 2025/02/11 14:44:52 claudio Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -47,6 +47,7 @@ struct rsync {
 	char			*compdst; /* compare against directory */
 	unsigned int		 id; /* identity of request */
 	pid_t			 pid; /* pid of process or 0 if unassociated */
+	int			 term_sent;
 };
 
 static TAILQ_HEAD(, rsync)	states = TAILQ_HEAD_INITIALIZER(states);
@@ -207,10 +208,27 @@ rsync_free(struct rsync *s)
 	free(s);
 }
 
+static int
+rsync_status(struct rsync *s, int st, int *rc)
+{
+	if (WIFEXITED(st)) {
+		if (WEXITSTATUS(st) == 0)
+			return 1;
+		warnx("rsync %s failed", s->uri);
+	} else if (WIFSIGNALED(st)) {
+		warnx("rsync %s terminated; signal %d", s->uri, WTERMSIG(st));
+		if (!s->term_sent || WTERMSIG(st) != SIGTERM)
+			*rc = 1;
+	} else {	/* should not be possible */
+		warnx("rsync %s terminated abnormally", s->uri);
+		*rc = 1;
+	}
+	return 0;
+}
+
 static void
 proc_child(int signal)
 {
-
 	/* Nothing: just discard. */
 }
 
@@ -323,7 +341,7 @@ proc_rsync(char *prog, char *bind_addr, int fd)
 			 */
 
 			while ((pid = waitpid(WAIT_ANY, &st, WNOHANG)) > 0) {
-				int ok = 1;
+				int ok;
 
 				TAILQ_FOREACH(s, &states, entry)
 					if (s->pid == pid)
@@ -331,15 +349,7 @@ proc_rsync(char *prog, char *bind_addr, int fd)
 				if (s == NULL)
 					errx(1, "waitpid: %d unexpected", pid);
 
-				if (!WIFEXITED(st)) {
-					warnx("rsync %s terminated abnormally",
-					    s->uri);
-					rc = 1;
-					ok = 0;
-				} else if (WEXITSTATUS(st) != 0) {
-					warnx("rsync %s failed", s->uri);
-					ok = 0;
-				}
+				ok = rsync_status(s, st, &rc);
 
 				b = io_new_buffer();
 				io_simple_buffer(b, &s->id, sizeof(s->id));
@@ -395,9 +405,10 @@ proc_rsync(char *prog, char *bind_addr, int fd)
 					if (s->id == id)
 						break;
 				if (s != NULL) {
-					if (s->pid != 0)
+					if (s->pid != 0) {
 						kill(s->pid, SIGTERM);
-					else
+						s->term_sent = 1;
+					} else
 						rsync_free(s);
 				}
 			}
