@@ -1,4 +1,4 @@
-/*	$OpenBSD: tal.c,v 1.40 2024/03/22 03:38:12 job Exp $ */
+/*	$OpenBSD: tal.c,v 1.41 2024/11/13 12:51:04 tb Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -96,14 +96,14 @@ tal_parse_buffer(const char *fn, char *buf, size_t len)
 
 		/* Append to list of URIs. */
 		tal->uri = reallocarray(tal->uri,
-		    tal->urisz + 1, sizeof(char *));
+		    tal->num_uris + 1, sizeof(char *));
 		if (tal->uri == NULL)
 			err(1, NULL);
 
-		tal->uri[tal->urisz] = strdup(line);
-		if (tal->uri[tal->urisz] == NULL)
+		tal->uri[tal->num_uris] = strdup(line);
+		if (tal->uri[tal->num_uris] == NULL)
 			err(1, NULL);
-		tal->urisz++;
+		tal->num_uris++;
 
 		f = strrchr(line, '/') + 1; /* can not fail */
 		if (file) {
@@ -116,13 +116,13 @@ tal_parse_buffer(const char *fn, char *buf, size_t len)
 			file = f;
 	}
 
-	if (tal->urisz == 0) {
+	if (tal->num_uris == 0) {
 		warnx("%s: no URIs in TAL file", fn);
 		goto out;
 	}
 
 	/* sort uri lexicographically so https:// is preferred */
-	qsort(tal->uri, tal->urisz, sizeof(tal->uri[0]), tal_cmp);
+	qsort(tal->uri, tal->num_uris, sizeof(tal->uri[0]), tal_cmp);
 
 	/* Now the Base64-encoded public key. */
 	if ((base64_decode(buf, len, &der, &dersz)) == -1) {
@@ -195,7 +195,7 @@ tal_free(struct tal *p)
 		return;
 
 	if (p->uri != NULL)
-		for (i = 0; i < p->urisz; i++)
+		for (i = 0; i < p->num_uris; i++)
 			free(p->uri[i]);
 
 	free(p->pkey);
@@ -216,9 +216,9 @@ tal_buffer(struct ibuf *b, const struct tal *p)
 	io_simple_buffer(b, &p->id, sizeof(p->id));
 	io_buf_buffer(b, p->pkey, p->pkeysz);
 	io_str_buffer(b, p->descr);
-	io_simple_buffer(b, &p->urisz, sizeof(p->urisz));
+	io_simple_buffer(b, &p->num_uris, sizeof(p->num_uris));
 
-	for (i = 0; i < p->urisz; i++)
+	for (i = 0; i < p->num_uris; i++)
 		io_str_buffer(b, p->uri[i]);
 }
 
@@ -239,15 +239,15 @@ tal_read(struct ibuf *b)
 	io_read_buf(b, &p->id, sizeof(p->id));
 	io_read_buf_alloc(b, (void **)&p->pkey, &p->pkeysz);
 	io_read_str(b, &p->descr);
-	io_read_buf(b, &p->urisz, sizeof(p->urisz));
+	io_read_buf(b, &p->num_uris, sizeof(p->num_uris));
 	assert(p->pkeysz > 0);
 	assert(p->descr);
-	assert(p->urisz > 0);
+	assert(p->num_uris > 0);
 
-	if ((p->uri = calloc(p->urisz, sizeof(char *))) == NULL)
+	if ((p->uri = calloc(p->num_uris, sizeof(char *))) == NULL)
 		err(1, NULL);
 
-	for (i = 0; i < p->urisz; i++) {
+	for (i = 0; i < p->num_uris; i++) {
 		io_read_str(b, &p->uri[i]);
 		assert(p->uri[i]);
 	}
